==> seedsui-react-2.6.2.tgz: package/es/OnOff/OnOff.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var OnOff = (_temp = _class = function (_Component) {
  _inherits(OnOff, _Component);

  function OnOff(props) {
    _classCallCheck(this, OnOff);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.onClick = function () {
      var _this$props = _this.props,
          readOnly = _this$props.readOnly,
          checked = _this$props.checked,
          onClick = _this$props.onClick;

      if (readOnly) return;
      if (onClick) {
        if (checked) onClick(true);else onClick(false);
      }
    };

    _this.state = {};
    return _this;
  }

  OnOff.prototype.render = function render() {
    var _props = this.props,
        className = _props.className,
        style = _props.style,
        checked = _props.checked,
        onCaption = _props.onCaption,
        offCaption = _props.offCaption,
        readOnly = _props.readOnly,
        onClick = _props.onClick,
        others = _objectWithoutProperties(_props, ['className', 'style', 'checked', 'onCaption', 'offCaption', 'readOnly', 'onClick']);

    return React.createElement(
      'div',
      _extends({ className: 'onoff' + (className ? ' ' + className : '') + (onCaption && offCaption ? '' : ' notext') + (checked ? ' active' : ''), style: style, 'data-on': onCaption, 'data-off': offCaption, onClick: this.onClick }, others),
      React.createElement('div', { className: 'onoff-handle' })
    );
  };

  return OnOff;
}(Component), _class.defaultProps = {
  onCaption: '',
  offCaption: ''
}, _temp);
export { OnOff as default };
OnOff.propTypes = process.env.NODE_ENV !== "production" ? {
  className: PropTypes.string,
  style: PropTypes.object,
  readOnly: PropTypes.bool,
  checked: PropTypes.bool,
  onCaption: PropTypes.string,
  offCaption: PropTypes.string,
  onClick: PropTypes.func
} : {};

==> seedsui-react-2.7.9.tgz: package/es/OnOff/OnOff.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var OnOff = (_temp = _class = function (_Component) {
  _inherits(OnOff, _Component);

  function OnOff(props) {
    _classCallCheck(this, OnOff);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  OnOff.prototype.render = function render() {
    var _props = this.props,
        checked = _props.checked,
        _props$onAttribute = _props.onAttribute,
        onAttribute = _props$onAttribute === undefined ? {} : _props$onAttribute,
        _props$offAttribute = _props.offAttribute,
        offAttribute = _props$offAttribute === undefined ? {} : _props$offAttribute,
        readOnly = _props.readOnly,
        disabled = _props.disabled,
        _onClick = _props.onClick,
        others = _objectWithoutProperties(_props, ['checked', 'onAttribute', 'offAttribute', 'readOnly', 'disabled', 'onClick']);

    return React.createElement(
      'div',
      _extends({}, others, { className: 'onoff' + (others.className ? ' ' + others.className : '') + (onAttribute.caption && offAttribute.caption ? '' : ' notext') + (checked ? ' active' : ''), 'data-on': onAttribute.caption || '', 'data-off': offAttribute.caption || '', 'data-readonly': readOnly, 'data-disabled': disabled, onClick: function onClick(e) {
          return _onClick(e, checked);
        } }),
      React.createElement('div', { className: 'onoff-handle' })
    );
  };

  return OnOff;
}(Component), _class.defaultProps = {}, _temp);
export { OnOff as default };
OnOff.propTypes = process.env.NODE_ENV !== "production" ? {
  readOnly: PropTypes.bool,
  disabled: PropTypes.bool,
  checked: PropTypes.bool,
  onAttribute: PropTypes.object,
  offAttribute: PropTypes.object,
  onClick: PropTypes.func
} : {};
